==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/ColumnChooserDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnChooserDescription } from "./ColumnChooserDescription";
/**
 * @hidden
 */
export let ColumnChooserDescriptionMetadata = /*@__PURE__*/ (() => {
    class ColumnChooserDescriptionMetadata extends Base {
        static b(a) {
            if (ColumnChooserDescriptionMetadata.a == null) {
                ColumnChooserDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ColumnChooserDescriptionMetadata.c(ColumnChooserDescriptionMetadata.a);
            }
            if (a.j(ColumnChooserDescriptionMetadata.a)) {
                return;
            }
            a.y(ColumnChooserDescriptionMetadata.a);
        }
        static c(a) {
            a.item("TargetGridRef", "(w:TargetGrid,wf:TargetGrid)DataRef::object");
            a.item("Title", "String");
            a.item("TitleFontFamily", "(w:TitleFontFamily/FontFamilyTransform,xam:TitleFontFamily,wf:TitleFontFamily,web:titleStyle/FontFamilyTransform)String");
            a.item("TitleFontSize", "(w:TitleFontSize,xam:TitleFontSize,wf:TitleFontSize,web:titleStyle/FontSizeTransform)Number:double");
            a.item("TitleFontStyle", "(w:TitleFontStyle/FontStyleTransform,xam:TitleFontFamily/FontStyleTransform,wf:TitleFontFamily/FontStyleTransform,web:titleStyle/FontStyleTransform)String");
            a.item("TitleFontWeight", "(w:TitleFontWeight/FontWeightTransform,xam:TitleFontFamily/FontWeightTransform,wf:TitleFontFamily/FontWeightTransform,web:titleStyle/FontWeightTransform)String");
            a.item("TitleColor", "Brush");
            a.item("FilterPlaceholderText", "String");
            a.item("BaseTheme", "ExportedType:string:BaseControlTheme");
            a.item("BaseTheme@names", "Default;DenaliLight;MaterialLight");
            a.item("Density", "ExportedType:string:ControlDisplayDensity");
            a.item("Density@names", "Auto;Comfortable;Cosy;Compact");
            a.item("BackgroundColor", "Brush");
        }
        static d(a) {
            ColumnChooserDescriptionMetadata.b(a);
            a.aa("ColumnChooser", () => new ColumnChooserDescription());
            a.z("ColumnChooser", ColumnChooserDescriptionMetadata.a);
        }
    }
    ColumnChooserDescriptionMetadata.$t = /*@__PURE__*/ markType(ColumnChooserDescriptionMetadata, 'ColumnChooserDescriptionMetadata');
    ColumnChooserDescriptionMetadata.a = null;
    return ColumnChooserDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ColumnChooserDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnChooserDescription } from "./ColumnChooserDescription";
/**
 * @hidden
 */
export let ColumnChooserDescriptionMetadata = /*@__PURE__*/ (() => {
    class ColumnChooserDescriptionMetadata extends Base {
        static b(a) {
            if (ColumnChooserDescriptionMetadata.a == null) {
                ColumnChooserDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ColumnChooserDescriptionMetadata.c(ColumnChooserDescriptionMetadata.a);
            }
            if (a.k(ColumnChooserDescriptionMetadata.a)) {
                return;
            }
            a.aa(ColumnChooserDescriptionMetadata.a);
        }
        static c(a) {
            a.item("TargetGridRef", "(w:TargetGrid,wf:TargetGrid)DataRef::object");
            a.item("Title", "String");
            a.item("TitleFontFamily", "(w:TitleFontFamily/FontFamilyTransform,xam:TitleFontFamily,wf:TitleFontFamily,web:titleStyle/FontFamilyTransform)String");
            a.item("TitleFontSize", "(w:TitleFontSize,xam:TitleFontSize,wf:TitleFontSize,web:titleStyle/FontSizeTransform)Number:double");
            a.item("TitleFontStyle", "(w:TitleFontStyle/FontStyleTransform,xam:TitleFontFamily/FontStyleTransform,wf:TitleFontFamily/FontStyleTransform,web:titleStyle/FontStyleTransform)String");
            a.item("TitleFontWeight", "(w:TitleFontWeight/FontWeightTransform,xam:TitleFontFamily/FontWeightTransform,wf:TitleFontFamily/FontWeightTransform,web:titleStyle/FontWeightTransform)String");
            a.item("TitleColor", "Brush");
            a.item("FilterPlaceholderText", "String");
            a.item("BaseTheme", "ExportedType:string:BaseControlTheme");
            a.item("BaseTheme@names", "Default;DenaliLight;MaterialLight");
            a.item("Density", "ExportedType:string:ControlDisplayDensity");
            a.item("Density@names", "Auto;Comfortable;Cosy;Compact");
            a.item("BackgroundColor", "Brush");
        }
        static d(a) {
            ColumnChooserDescriptionMetadata.b(a);
            a.ac("ColumnChooser", () => new ColumnChooserDescription());
            a.ab("ColumnChooser", ColumnChooserDescriptionMetadata.a);
        }
    }
    ColumnChooserDescriptionMetadata.$t = /*@__PURE__*/ markType(ColumnChooserDescriptionMetadata, 'ColumnChooserDescriptionMetadata');
    ColumnChooserDescriptionMetadata.a = null;
    return ColumnChooserDescriptionMetadata;
})();
